Module: URI
- Defined in:
- lib/extensions.rb
Overview
Hack URI::HTTP to include a method that gets us both the path and the querystring since path_query is private
Defined Under Namespace
Classes: HTTP
Hack URI::HTTP to include a method that gets us both the path and the querystring since path_query is private
Classes: HTTP